# Vacasa API
# Copyright 2018 John W. Miller
# See LICENSE for details.

"""
Spoonacular APIs library
"""
__version__ = '0.0.1'
__author__ = 'John W. Miller'
__description__ = 'A Python client for the Vacasa Connect API'
__license__ = 'MIT'

import sys
from .api import API
